@@ -1,7 +1,7 @@
 package Path::Router::Route::Match;
 use Moose;
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.02';
 our $AUTHORITY = 'cpan:STEVAN';
 
 has 'path'    => (is => 'ro', isa => 'Str',     required => 1);
@@ -24,26 +24,37 @@ __END__
 
 Path::Router::Route::Match - The result of a Path::Router match
 
-=head1 SYNOPSIS
-
-  use Path::Router::Route::Match;
-
 =head1 DESCRIPTION
 
+This is the object returned from calling C<match> on a L<Path::Router>
+instance. It contains all the information you would need to do any 
+dispatching nessecary. 
+
 =head1 METHODS 
 
 =over 4
 
+=item B<path>
+
+This is the path that was matched.
+
 =item B<mapping>
 
-=item B<meta>
-
-=item B<path>
+This is the mapping of your router part names to the actual parts of 
+the path. If your route had no "variables", then this will be an empty 
+HASH ref.
 
 =item B<route>
 
+This is the L<Path::Router::Route> instance that was matched.
+
 =item B<target>
 
+This method simply delegates to the C<target> method of the C<route>
+that was matched.
+
+=item B<meta>
+
 =back
 
 =head1 BUGS
